@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 {
-  $CPAN::Perl::Releases::VERSION = '0.86';
+  $CPAN::Perl::Releases::VERSION = '0.88';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -140,6 +140,10 @@ our $data =
     "tar.bz2" => "D/DO/DOM/perl-5.12.5-RC2.tar.bz2",
     "tar.gz" => "D/DO/DOM/perl-5.12.5-RC2.tar.gz",
   },
+  "5.12.5" => {
+    "tar.bz2" => "D/DO/DOM/perl-5.12.5.tar.bz2",
+    "tar.gz" => "D/DO/DOM/perl-5.12.5.tar.gz",
+  },
   "5.13.0" => {
     "tar.bz2" => "L/LB/LBROCARD/perl-5.13.0.tar.bz2",
     "tar.gz" => "L/LB/LBROCARD/perl-5.13.0.tar.gz",
@@ -435,7 +439,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 0.86
+version 0.88
 
 =head1 SYNOPSIS
 
